@@ -15,11 +15,23 @@
 #include <libsoup/soup-message.h>
 #include <libsoup/soup-misc.h>
 
-typedef struct _SoupAuth SoupAuth;
+typedef   enum _SoupAuthStatus SoupAuthStatus;
+typedef struct _SoupAuth       SoupAuth;
+
+enum _SoupAuthStatus {
+	SOUP_AUTH_STATUS_INVALID = 0,
+	SOUP_AUTH_STATUS_PENDING,
+	SOUP_AUTH_STATUS_FAILED,
+	SOUP_AUTH_STATUS_SUCCESSFUL
+};
+
 struct _SoupAuth {
 	SoupAuthType  type;
 	gchar        *realm;
 
+	SoupAuthStatus status;
+	SoupMessage *controlling_msg;
+
 	gboolean (*compare_func) (SoupAuth      *a, 
 				  SoupAuth      *b);
 
@@ -40,6 +52,9 @@ SoupAuth *soup_auth_lookup                 (SoupContext   *ctx);
 void      soup_auth_set_context            (SoupAuth      *auth,
 					    SoupContext   *ctx);
 
+void      soup_auth_invalidate             (SoupAuth      *auth,
+					    SoupContext   *ctx);
+
 SoupAuth *soup_auth_new_from_header_list   (const SoupUri *uri,
 					    const GSList  *header);
 
